@@ -5,6 +5,8 @@ class AbstractSonar(ABC):
 
     def __init__(self, personal_access_token, sonar_url):
 
+        self.personal_access_token = personal_access_token
+        self.sonar_url = sonar_url
         self.sonar = SonarCloudClient(sonarcloud_url = sonar_url, token = personal_access_token)
 
     
