@@ -1,6 +1,6 @@
 import logging
 logging.basicConfig(level=logging.INFO)
-from sonarcloudX1.abstract import AbstractSonar
+from sonarcloudx1.abstract import AbstractSonar
 
 # Represents a software Project
 class Project(AbstractSonar):
